@@ -1,9 +1,7 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import FormLabel from '../../components/style/form-label';
-
-var tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
-var firstTdStyle = { width: '6em' };
+import { FormLabel } from '../../components/style/export';
+import PropertyStyle from './shared-property-style';
 
 export default function PropertyReadOnly(_ref) {
   var value = _ref.value,
@@ -15,7 +13,7 @@ export default function PropertyReadOnly(_ref) {
 
   return React.createElement(
     'table',
-    { className: 'PropertyReadOnly', style: tableStyle },
+    { className: 'PropertyReadOnly', style: PropertyStyle.tableStyle },
     React.createElement(
       'tbody',
       null,
@@ -24,7 +22,7 @@ export default function PropertyReadOnly(_ref) {
         null,
         React.createElement(
           'td',
-          { style: firstTdStyle },
+          { style: PropertyStyle.firstTdStyle },
           React.createElement(
             FormLabel,
             null,
