@@ -36,13 +36,12 @@ export default function Area(_ref) {
 
       return [x, y];
     });
-    var center = polylabel([polygon], 1.0);
-    var areaSize = areapolygon(polygon, false);
 
-    //subtract holes area
-    area.holes.forEach(function (areaID) {
-      var hole = layer.areas.get(areaID);
-      var holePolygon = hole.vertices.toArray().map(function (vertexID) {
+    var polygonWithHoles = polygon;
+
+    area.holes.forEach(function (holeID) {
+
+      var polygonHole = layer.areas.get(holeID).vertices.toArray().map(function (vertexID) {
         var _layer$vertices$get2 = layer.vertices.get(vertexID),
             x = _layer$vertices$get2.x,
             y = _layer$vertices$get2.y;
@@ -50,6 +49,22 @@ export default function Area(_ref) {
         return [x, y];
       });
 
+      polygonWithHoles = polygonWithHoles.concat(polygonHole.reverse());
+    });
+
+    var center = polylabel([polygonWithHoles], 1.0);
+    var areaSize = areapolygon(polygon, false);
+
+    //subtract holes area
+    area.holes.forEach(function (areaID) {
+      var hole = layer.areas.get(areaID);
+      var holePolygon = hole.vertices.toArray().map(function (vertexID) {
+        var _layer$vertices$get3 = layer.vertices.get(vertexID),
+            x = _layer$vertices$get3.x,
+            y = _layer$vertices$get3.y;
+
+        return [x, y];
+      });
       areaSize -= areapolygon(holePolygon, false);
     });
 
