@@ -1,7 +1,7 @@
 import React from 'react';
 import PropTypes from 'prop-types';
 
-export default function PropertyHidden({value, onUpdate, configs, sourceElement, internalState}) {
+export default function PropertyHidden({value, onUpdate, configs, sourceElement, internalState, state}) {
   return null
 }
 
@@ -10,5 +10,6 @@ PropertyHidden.propTypes = {
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
   sourceElement: PropTypes.object,
-  internalState: PropTypes.object
+  internalState: PropTypes.object,
+  state: PropTypes.object.isRequired
 };
