@@ -10,6 +10,7 @@ import ReactPlannerComponents from './components/export';
 import ReactPlannerActions from './actions/export';
 import ReactPlannerReducers from './reducers/export';
 import ElementsFactories from './catalog/factories/export';
+import ReactPlannerUtils from './utils/export';
 
 export {
   Catalog,
@@ -23,5 +24,6 @@ export {
   ReactPlannerReducers,
   ReactPlannerActions,
   ReactPlannerComponents,
-  ReactPlannerSharedStyle
+  ReactPlannerSharedStyle,
+  ReactPlannerUtils
 };
