@@ -20,7 +20,7 @@ export function addLine(layer, type, x0, y0, x1, y1, catalog, properties = {}) {
 
     line = catalog.factoryElement(type, {
       id: lineID,
-      name: NameGenerator.generateName('lines', catalog.get('elements').get(type).get('info').get('title')),
+      name: NameGenerator.generateName('lines', catalog.getIn(['elements', type, 'info', 'title'])),
       vertices: new List([v0.id, v1.id]),
       type
     }, properties);
@@ -166,7 +166,7 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
         v0, v1
       );
 
-      if (intersection.type === "colinear") {
+      if (intersection.type === 'colinear') {
         if (!oldHoles) {
           oldHoles = [];
         }
@@ -197,7 +197,7 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
         points.push(v0, v1);
       }
 
-      if (intersection.type === "intersecting" && (!hasCommonEndpoint)) {
+      if (intersection.type === 'intersecting' && (!hasCommonEndpoint)) {
         splitLine(layer, line.id, intersection.point.x, intersection.point.y, catalog);
         points.push(intersection.point);
       }
@@ -236,11 +236,11 @@ export function removeVertex(layer, vertexID, relatedPrototype, relatedID) {
     return related.delete(index);
   });
 
-  if (vertex.areas.size + vertex.lines.size === 0) {
-    layer = layer.deleteIn(['vertices', vertex.id]);
-  } else {
-    layer = layer.setIn(['vertices', vertex.id], vertex);
-  }
+  layer =
+    vertex.areas.size || vertex.lines.size ?
+    layer.setIn(['vertices', vertex.id], vertex) :
+    layer.deleteIn(['vertices', vertex.id]);
+
   return {layer, vertex};
 }
 
@@ -250,8 +250,7 @@ export function mergeEqualsVertices(layer, vertexID) {
   let vertex = layer.getIn(['vertices', vertexID]);
 
   let doubleVertices = layer.vertices
-    .filter(v => v.id !== vertexID)
-    .filter(v => Geometry.samePoints(vertex, v));
+    .filter(v => v.id !== vertexID && Geometry.samePoints(vertex, v));
 
   if (doubleVertices.isEmpty()) return layer;
 
@@ -313,13 +312,9 @@ function opSetProperties(layer, prototype, ID, properties) {
 }
 
 function opUpdateProperties(layer, prototype, ID, properties) {
-  let newProp = fromJS(properties);
-  newProp.forEach( ( v, k ) =>
-  {
-    if( layer.getIn([prototype, ID, 'properties', k]) )
-    {
-      layer = layer.setIn([prototype, ID, 'properties', k], v);
-    }
+  fromJS(properties).forEach( ( v, k ) => {
+    if( layer.hasIn([prototype, ID, 'properties', k]) )
+      layer.mergeIn([prototype, ID, 'properties', k], v);
   });
 }
 
@@ -414,18 +409,14 @@ export function addArea(layer, type, verticesCoords, catalog) {
   layer = layer.withMutations(layer => {
     let areaID = IDBroker.acquireID();
 
-    let vertices = [];
-    verticesCoords.forEach(({x, y}) => {
-      let {vertex} = addVertex(layer, x, y, 'areas', areaID);
-      vertices.push(vertex.id);
-    });
+    let vertices = verticesCoords.map( ( v ) => addVertex(layer, v.x, v.y, 'areas', areaID).vertex.id );
 
     area = catalog.factoryElement(type, {
       id: areaID,
-      name: NameGenerator.generateName('areas', catalog.get('elements').get(type).get('info').get('title')),
+      name: NameGenerator.generateName('areas', catalog.getIn(['elements', type, 'info', 'title'])),
       type,
-      prototype: "areas",
-      vertices: new List(vertices)
+      prototype: 'areas',
+      vertices
     });
 
     layer.setIn(['areas', areaID], area);
@@ -476,8 +467,8 @@ function ContainsPoint(polygon, pointX, pointY) {
     ay = by;
     bx = polygon[2 * i] - pointX;
     by = polygon[2 * i + 1] - pointY;
-    if (ay < 0 && by < 0) continue;  // both "up" or both "down"
-    if (ay > 0 && by > 0) continue;  // both "up" or both "down"
+    if (ay < 0 && by < 0) continue;  // both 'up' or both 'down'
+    if (ay > 0 && by > 0) continue;  // both 'up' or both 'down'
     if (ax < 0 && bx < 0) continue;   // both points on the left
 
     if (ay === by && Math.min(ax, bx) < 0) return true;
@@ -512,23 +503,13 @@ export function detectAndUpdateAreas(layer, catalog) {
 
   let innerCyclesByVerticesArrayIndex = calculateInnerCyles(verticesArray, linesArray);
 
-  let innerCyclesByVerticesID = new List(innerCyclesByVerticesArrayIndex)
-    .map(cycle => new List(cycle.map(vertexIndex => verticesArrayIndex_to_vertexID[vertexIndex])));
+  let innerCyclesByVerticesID = innerCyclesByVerticesArrayIndex
+    .map(cycle => cycle.map(vertexIndex => verticesArrayIndex_to_vertexID[vertexIndex]));
 
   // All area vertices should be ordered in counterclockwise order
-  innerCyclesByVerticesID = innerCyclesByVerticesID.withMutations(innerCyclesByVerticesID => {
-    innerCyclesByVerticesID.forEach((innerCycle, index) => {
-      let innerCycleWithCoords = innerCycle.map(vertexID => {
-        return new Map({
-          x: layer.vertices.get(vertexID).x,
-          y: layer.vertices.get(vertexID).y
-        });
-      });
-      if (isClockWiseOrder(innerCycleWithCoords)) {
-        innerCyclesByVerticesID.set(index, innerCyclesByVerticesID.get(index).reverse());
-      }
-    });
-  });
+  innerCyclesByVerticesID = innerCyclesByVerticesID.map( ( area ) =>
+    isClockWiseOrder( area.map(vertexID => layer.vertices.get(vertexID) ) ) ? area.reverse() : area
+  );
 
   let areaIDs = [];
 
@@ -554,13 +535,9 @@ export function detectAndUpdateAreas(layer, catalog) {
     });
 
     // Build a relationship between areas and their coordinates
-    let verticesCoordsForArea = areaIDs.map(areaID => {
-      return {
-        id: areaID,
-        vertices: layer.areas.get(areaID).vertices.map(vertexID => {
-          return new List([layer.vertices.get(vertexID).x, layer.vertices.get(vertexID).y]);
-        })
-      }
+    let verticesCoordsForArea = areaIDs.map(id => {
+      let vertices = layer.areas.get(id).vertices.map(vertexID => layer.vertices.get(vertexID));
+      return { id, vertices };
     });
 
     // Find all holes for an area
@@ -614,7 +591,7 @@ export function addHole(layer, type, lineID, offset, catalog, properties = {}) {
 
     hole = catalog.factoryElement(type, {
       id: holeID,
-      name: NameGenerator.generateName('holes', catalog.get('elements').get(type).get('info').get('title')),
+      name: NameGenerator.generateName('holes', catalog.getIn(['elements', type, 'info', 'title'])),
       type,
       offset,
       line: lineID
@@ -650,7 +627,7 @@ export function addItem(layer, type, x, y, width, height, rotation, catalog) {
 
     item = catalog.factoryElement(type, {
       id: itemID,
-      name: NameGenerator.generateName('items', catalog.get('elements').get(type).get('info').get('title')),
+      name: NameGenerator.generateName('items', catalog.getIn(['elements', type, 'info', 'title'])),
       type,
       height,
       width,
